#include <cstdio>
#include <stdexcept>
#include <unistd.h>
#include <pwd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <assert.h>
#include <sqlite3.h>

sqlite3* _sqlite3 = nullptr;

bool directory_exists(const char* fs_path)	
{
	struct stat ss;
	if (stat(fs_path, &ss) != 0)
		return false;
	else
		return (ss.st_mode & S_IFMT) == S_IFDIR;
}

bool file_exists(const char* file_path)	
{
	struct stat ss;
	if (stat(file_path, &ss) != 0)
		return false;
	else
		return (ss.st_mode & S_IFMT) == S_IFREG;
}

int select_callback(void* p, int count, char** data, char** col_name)
{
	for (size_t i = 0; i < count; i++)
	{
		printf("%s: %s \t", *(col_name+i), *(data+i));
	}
	printf("\n");
	return 0;
}

int main(int argc, char** argv)
{
	try
	{
		std::string db_file = getenv("HOME");
		if (!directory_exists(db_file.c_str()))
			db_file = getpwuid(getuid())->pw_dir;
		if (!directory_exists(db_file.c_str()))
			throw std::runtime_error("Nepodařilo se zjistit domovský adresář.");
		db_file.append("/Dokumenty/test.db");
		printf("Soubor databáze: %s\n", db_file.c_str());
		int ires = sqlite3_open(db_file.c_str(), &_sqlite3);
		if (ires != SQLITE_OK)
			throw std::runtime_error(sqlite3_errstr(ires));
		ires = sqlite3_exec(_sqlite3, "CREATE TABLE IF NOT EXISTS polozky (id INTEGER PRIMARY KEY,"
			" cislo INTEGER DEFAULT 0, nazev TEXT)", nullptr, nullptr, nullptr);
		if (ires != SQLITE_OK)
			throw std::runtime_error(sqlite3_errstr(ires));
		ires = sqlite3_exec(_sqlite3, "INSERT INTO polozky (cislo, nazev) VALUES (1, 'první položka')",
			nullptr, nullptr, nullptr);
		if (ires != SQLITE_OK)
			throw std::runtime_error(sqlite3_errstr(ires));
		ires = sqlite3_exec(_sqlite3, "INSERT INTO polozky (cislo, nazev) VALUES (2, 'druhá položka')",
			nullptr, nullptr, nullptr);
		if (ires != SQLITE_OK)
			throw std::runtime_error(sqlite3_errstr(ires));
		ires = sqlite3_exec(_sqlite3, "SELECT * FROM polozky",
			select_callback, nullptr, nullptr);
		if (ires != SQLITE_OK)
			throw std::runtime_error(sqlite3_errstr(ires));
		sqlite3_close(_sqlite3);
		printf("\nok\n");
		return EXIT_SUCCESS;
	}
	catch(const std::exception& e)
	{
		printf(e.what());
		if (_sqlite3)
			sqlite3_close(_sqlite3);
		return EXIT_FAILURE;
	}
	
}

